aboutsummaryrefslogtreecommitdiff
path: root/gcc
diff options
context:
space:
mode:
authorKazu Hirata <kazu@codesourcery.com>2005-09-06 02:12:30 +0000
committerKazu Hirata <kazu@gcc.gnu.org>2005-09-06 02:12:30 +0000
commit1634705dd6bf842b1dca21c690a38b3fdbef53a4 (patch)
tree83dd791d18b8133d0e69edb0dec8d92f1dd2a805 /gcc
parent57b51d4d635b49b94ace7d83ef0294f58dcb64f7 (diff)
downloadgcc-1634705dd6bf842b1dca21c690a38b3fdbef53a4.zip
gcc-1634705dd6bf842b1dca21c690a38b3fdbef53a4.tar.gz
gcc-1634705dd6bf842b1dca21c690a38b3fdbef53a4.tar.bz2
cp-tree.h, [...]: Fix comment typos.
* cp-tree.h, decl.c, decl2.c, semantics.c: Fix comment typos. Follow spelling conventions. From-SVN: r103926
Diffstat (limited to 'gcc')
-rw-r--r--gcc/cp/ChangeLog5
-rw-r--r--gcc/cp/cp-tree.h8
-rw-r--r--gcc/cp/decl.c2
-rw-r--r--gcc/cp/decl2.c2
-rw-r--r--gcc/cp/semantics.c2
5 files changed, 12 insertions, 7 deletions
diff --git a/gcc/cp/ChangeLog b/gcc/cp/ChangeLog
index 97ba826..4c73cfc 100644
--- a/gcc/cp/ChangeLog
+++ b/gcc/cp/ChangeLog
@@ -1,3 +1,8 @@
+2005-09-06 Kazu Hirata <kazu@codesourcery.com>
+
+ * cp-tree.h, decl.c, decl2.c, semantics.c: Fix comment typos.
+ Follow spelling conventions.
+
2005-09-05 Mark Mitchell <mark@codesourcery.com>
PR c++/23667
diff --git a/gcc/cp/decl.c b/gcc/cp/decl.c
index a32be09..1d887bf 100644
--- a/gcc/cp/decl.c
+++ b/gcc/cp/decl.c
@@ -4924,7 +4924,7 @@ cp_finish_decl (tree decl, tree init, tree asmspec_tree, int flags)
}
/* Check that the initializer for a static data member was a
- constant. Althouh we check in the parser that the
+ constant. Although we check in the parser that the
initializer is an integral constant expression, we do not
simplify division-by-zero at the point at which it
occurs. Therefore, in:
diff --git a/gcc/cp/decl2.c b/gcc/cp/decl2.c
index 75ec65f..87ef858 100644
--- a/gcc/cp/decl2.c
+++ b/gcc/cp/decl2.c
@@ -1790,7 +1790,7 @@ import_export_decl (tree decl)
/* The generic C++ ABI says that class data is always
COMDAT, even if there is a key function. Some
variants (e.g., the ARM EABI) says that class data
- only has COMDAT linkage if the the class data might
+ only has COMDAT linkage if the class data might
be emitted in more than one translation unit. */
if (!CLASSTYPE_KEY_METHOD (class_type)
|| targetm.cxx.class_data_always_comdat ())
diff --git a/gcc/cp/semantics.c b/gcc/cp/semantics.c
index 11552db..074a7fd 100644
--- a/gcc/cp/semantics.c
+++ b/gcc/cp/semantics.c
@@ -1567,7 +1567,7 @@ finish_stmt_expr_expr (tree expr, tree stmt_expr)
expression. */
TREE_TYPE (stmt_expr) = type;
/* We must take particular care if TYPE is a class type. In
- paticular if EXPR creates a temporary of class type, then it
+ particular if EXPR creates a temporary of class type, then it
must be destroyed at the semicolon terminating the last
statement -- but we must make a copy before that happens.
diff --git a/gcc/cp/cp-tree.h b/gcc/cp/cp-tree.h
index e8d5fe7..4d5d618 100644
--- a/gcc/cp/cp-tree.h
+++ b/gcc/cp/cp-tree.h
@@ -1177,12 +1177,12 @@ struct lang_type GTY(())
/* Mark bits for repeated base checks. */
#define TYPE_MARKED_P(NODE) TREE_LANG_FLAG_6 (TYPE_CHECK (NODE))
/* Non-zero if the class NODE has multiple paths to the same (virtual)
base object. */
#define CLASSTYPE_DIAMOND_SHAPED_P(NODE) \
(LANG_TYPE_CLASS_CHECK(NODE)->diamond_shaped)
/* Non-zero if the class NODE has multiple instances of the same base
type. */
#define CLASSTYPE_REPEATED_BASE_P(NODE) \
(LANG_TYPE_CLASS_CHECK(NODE)->repeated_base)
@@ -2065,7 +2065,7 @@ extern void decl_shadowed_for_var_insert (tree, tree);
template.
In general, DECL_TEMPLATE_INFO is non-NULL only if
- DECL_USE_TEMPLATE is non-zero. However, for friends, we sometimes
+ DECL_USE_TEMPLATE is nonzero. However, for friends, we sometimes
have DECL_TEMPLATE_INFO even when DECL_USE_TEMPLATE is zero.
Consider:
@@ -2784,7 +2784,7 @@ extern void decl_shadowed_for_var_insert (tree, tree);
2=explicit template specialization, e.g. int min<int> (int, int);
3=explicit template instantiation, e.g. template int min<int> (int, int);
- If DECL_USE_TEMPLATE is non-zero, then DECL_TEMPLATE_INFO will also
+ If DECL_USE_TEMPLATE is nonzero, then DECL_TEMPLATE_INFO will also
be non-NULL. */
#define DECL_USE_TEMPLATE(NODE) (DECL_LANG_SPECIFIC (NODE)->decl_flags.use_template)
@@ -1177,12 +1177,12 @@ struct lang_type GTY(())
/* Mark bits for repeated base checks. */
#define TYPE_MARKED_P(NODE) TREE_LANG_FLAG_6 (TYPE_CHECK (NODE))
-/* Non-zero if the class NODE has multiple paths to the same (virtual)
+/* Nonzero if the class NODE has multiple paths to the same (virtual)
base object. */
#define CLASSTYPE_DIAMOND_SHAPED_P(NODE) \
@@ -1177,12 +1177,12 @@ struct lang_type GTY(())
#define CLASSTYPE_DIAMOND_SHAPED_P(NODE) \
(LANG_TYPE_CLASS_CHECK(NODE)->diamond_shaped)
-/* Non-zero if the class NODE has multiple instances of the same base
+/* Nonzero if the class NODE has multiple instances of the same base
type. */
#define CLASSTYPE_REPEATED_BASE_P(NODE) \